import math

sub = lambda a,b: (a[0]-b[0],a[1]-b[1])
add = lambda a,b: (a[0]+b[0],a[1]+b[1])
mul = lambda v,s: (v[0]*s, v[1]*s)
div = lambda v,s: (v[0]/s, v[1]/s)

def hermite(control, a=0.5, resolution=10):
    control.insert(0, add(sub(control[0], control[1]), control[0]))
    control.append(add(control[-1], sub(control[-1], control[-2])))
    points = []
    for i in xrange(1, len(control)-2):
        ni = i+1
        P0 = control[i-1]
        P1 = control[i]
        P2 = control[ni]
        P3 = control[ni+1]
        T1 = mul(sub(P2,P0), a)
        T2 = mul(sub(P3,P1), a)
        for t in xrange(resolution+1):
            s = float(t) / resolution
            h1 = 2 * s ** 3 - 3 * s ** 2 + 1
            h2 = -2 * s ** 3 + 3 * s ** 2
            h3 = s ** 3 - 2 * s ** 2 + s
            h4 = s ** 3 - s ** 2
            p = add(add(mul(P1, h1),mul(P2,h2)),add(mul(T1, h3),mul(T2, h4)))
            points.append(p)
    return points



def sample(points, resolution=5):
    samples = [points.pop(0)]
    while points:
        P1 = samples[-1]
        P2 = points.pop(0)
        D = sub(P2, P1)
        M = math.sqrt(D[0]*D[0] + D[1]*D[1])

        if M < resolution: 
            continue

        U = mul(div(D, M), resolution)
        print U, M,resolution
        for i in xrange(math.floor((M/resolution))):
            samples.append(add(P1, mul(U, i)))

    return samples
            
            
        
        
         
        
        
